/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps.h
    \brief  API of the LCMAPS library
    \author Martijn Steenbakkers for the EU DataGrid.

    This header contains the declarations of the LCMAPS library functions:
    -# lcmaps_init(): To initialize the LCMAPS module
    -# lcmaps_run():  To do the user mapping
    -# lcmaps_run_without_credentials():  To do the user mapping, without credentials
    -# lcmaps_term(): To cleanly terminate the module
    \ingroup LcmapsInterface
*/
/*!
    \defgroup LcmapsInterface Interface to LCMAPS (library)
    \brief The API is available by including the header lcmaps.h
*/

#ifndef LCMAPS_H
#define LCMAPS_H

/******************************************************************************
                             Include header files
******************************************************************************/
#include <gssapi.h>
#include "lcmaps_types.h"

/******************************************************************************
 *                 Module definition
 *****************************************************************************/

/******************************************************************************
Function:   lcmaps_init
Description:
    Initialize LCMAPS module: 
    setup logging, error handling
    start PluginManager

Parameters:
    fp: file handle for logging (from gatekeeper)
Returns:
    0: initialization succeeded
    1: initialization failed
******************************************************************************/
extern int lcmaps_init(
        FILE* fp
);

/******************************************************************************
Function:   lcmaps_init_and_log
Description:
    Select logging type
    Start PluginManager:
    read from LCMAPS config file, the plugins to be loaded

Parameters:
    fp: file handle for logging (from gatekeeper or other previously opened file handle)
        If the file handle is zero, assume that only syslogging is requested
    logtype: type of logging (usrlog and/or syslog)

Returns:
    0: initialization succeeded
    1: initialization failed
******************************************************************************/
extern int lcmaps_init_and_log(
        FILE* fp,
        unsigned short logtype
);

/******************************************************************************
Function:   lcmaps_term
Description:
    Terminate LCMAPS module: 

Parameters:
Returns:
    0: termination succeeded
    1: termination failed
******************************************************************************/
extern int lcmaps_term();

/******************************************************************************
Function:   lcmaps_run
Description:
    do the user mapping

Parameters:
    request: JDL
    user_cred : user globus credential handle
Returns:
    0: authorization succeeded
    1: authorization failed
******************************************************************************/
#if ALLOW_EMPTY_CREDENTIALS
extern int lcmaps_run(
        char * user_dn_tmp,
        gss_cred_id_t user_cred,
        lcmaps_request_t request
);
#else
extern int lcmaps_run(
        gss_cred_id_t user_cred,
        lcmaps_request_t request
);
#endif

/******************************************************************************
Function:   lcmaps_run_and_return_username
Description:
    do the user mapping based on the provided list of policies (first successful
    policy found in the lcmaps policy file (lcmaps.db) will result in the user
    mapping) and return user name (needed for e.g. GridFTP)

Parameters:
    request     : JDL
    user_cred   : user globus credential handle
    usernamep   : pointer to user name (to be freed by calling application)
    npols       : number of policies to be considered for evaluation
    policynames : the names of the policies to be considered for evaluation

Returns:
    0: mapping succeeded
    1: mapping failed
******************************************************************************/
#if ALLOW_EMPTY_CREDENTIALS
extern int lcmaps_run_and_return_username(
        char * user_dn_tmp,
        gss_cred_id_t user_cred,
        lcmaps_request_t request,
        char ** usernamep,
        int npols,
        char ** policynames
);
#else
extern int lcmaps_run_and_return_username(
        gss_cred_id_t user_cred,
        lcmaps_request_t request,
        char ** usernamep,
        int npols,
        char ** policynames
);
#endif
/******************************************************************************
Function:   lcmaps_run_without_credentials
Description:
    do the user mapping without credentials, only the user DN

Parameters:
    user_dn_tmp: user DN
Returns:
    0: mapping succeeded
    1: mapping failed
******************************************************************************/
extern int lcmaps_run_without_credentials(
        char * user_dn_tmp
);
#endif /* LCMAPS_H */

/******************************************************************************
CVS Information:
    $Source: /local/reps/lcgware/fabric_mgt/gridification/lcmaps/include/lcmaps.h,v $
    $Date: 2004/09/20 10:12:33 $
    $Revision: 1.6 $
    $Author: maart $
******************************************************************************/
