/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     Oscar Koeroo <okoeroo@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_arguments.h
    \ingroup APIforLcmapsPlugins
    \author Martijn Steenbakkers and Oscar Koeroo for the EU DataGrid.
    \brief  Public header file to be used by plugins

    Routines to access the plugin arguments.

    The interface is composed of:
    -# lcmaps_setArgValue(): Set the value of argument with name argName of argType to value
    -# lcmaps_getArgValue(): Get the value of argument with name argName of argType
    -# lcmaps_findArgName(): Get index of argument with name argName
    -# lcmaps_cntArgs(): Count the number of arguments
*/

#ifndef LCMAPS_ARGUMENTS_H
#define LCMAPS_ARGUMENTS_H

/******************************************************************************
                               Type definitions
******************************************************************************/

/*!
    \struct lcmaps_argument_s
    \brief structure representing an LCMAPS plugin run argument
*/
/*!
    \typedef lcmaps_argument_t
    \brief Type of LCMAPS plugin run argument (to be passed to the plugin by plugin_run())
*/
typedef struct lcmaps_argument_s
{
    char *argName; /*!< name of argument */
    char *argType; /*!< type of the argument */
    int argInOut;  /*!< input or output argument (0 = false = Input / 1 = true = Out) */
    void *value;   /*!< value of argument */
} lcmaps_argument_t;


/******************************************************************************
 *                 Module definition
 *****************************************************************************/ 

/******************************************************************************
Function:   lcmaps_setArgValue
Description:
    Set the value of argType on the reserved place in values. 
    The place within values is determined by the place where argName is found
    in the arguments list

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    0:  success
    -1: failure (could not find structure with name argName)
******************************************************************************/
extern int         lcmaps_setArgValue(char *argName, char *argType, void *value,  int argcx, lcmaps_argument_t **argvx);

/******************************************************************************
Function:   lcmaps_getArgValue
Description:
    Gets the value of argType from values.
    The place within the lcmaps_argument_t values is determined by the argName listed in 
    lcmaps_argument_t *argvx.
    Returns a void pointer to the value.

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    void pointer to the value or NULL
******************************************************************************/
extern void *      lcmaps_getArgValue(char *argName, char *argType, int argcx, lcmaps_argument_t *argvx);

/******************************************************************************
Function:   lcmaps_findArgName
Description:
    Search for argName in the arguments list.
    Returns the index to lcmaps_argument_t element.

Parameters:
    argName: name of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    index to lcmaps_argument_t element
******************************************************************************/
extern int         lcmaps_findArgName(char *argName, int argcx, lcmaps_argument_t *argvx);

/******************************************************************************
Function:   lcmaps_findArgNameAndType
Description:
    Search for argName and Type in the arguments list.
    Returns the index to lcmaps_argument_t element.

Parameters:
    argName: name of argument
    argType: type of argument
    argcx:   number of arguments
    argvx:   array of arguments structures
Returns:
    index to lcmaps_argument_t element
******************************************************************************/
extern int         lcmaps_findArgNameAndType(char *argName, char *argType, int argcx, lcmaps_argument_t *argvx);

/******************************************************************************
Function:   lcmaps_cntArgs
Description:
    Count the number of arguments that are defined in a plug-in
    Returns this number.

Parameters:
    argvx:   array of arguments structures
Returns:
    the number of arguments
******************************************************************************/
extern int         lcmaps_cntArgs(lcmaps_argument_t *argvx);

#endif /* LCMAPS_ARGUMENTS_H */

/******************************************************************************
CVS Information:
    $Source: /local/reps/lcgware/fabric_mgt/gridification/lcmaps/include/lcmaps_arguments.h,v $
    $Date: 2004/09/20 10:12:33 $
    $Revision: 1.8 $
    $Author: maart $
******************************************************************************/
