/*                                                                                                            
 * Copyright (c) 2001 EU DataGrid.                                                                             
 * For license conditions see http://www.eu-datagrid.org/license.html                                          
 *
 * Copyright (c) 2001, 2002 by 
 *     Martijn Steenbakkers <martijn@nikhef.nl>,
 *     David Groep <davidg@nikhef.nl>,
 *     NIKHEF Amsterdam, the Netherlands
 */

/*!
    \file   lcmaps_vo_data.h
    \brief  LCMAPS module for creating and accessing VO data structures
    \author Martijn Steenbakkers for the EU DataGrid.

    The interface is composed of:
    -# lcmaps_createVoData(): create a VoData structure
    -# lcmaps_deleteVoData(): delete a VoData structure
    -# lcmaps_cleanVoData(): clean a VoData structure
    -# lcmaps_copyVoData(): copy (the contents of) a VoData structure
    -# lcmaps_printVoData(): print the contents of a VoData structure
    -# lcmaps_stringVoData(): cast a VoData structure into a string
    -# lcmaps_createVoMapping(): create a VoMapping structure
    -# lcmaps_deleteVoMapping(): delete a VoMapping structure
    -# lcmaps_cleanVoMapping(): clean a VoMapping structure
    -# lcmaps_copyVoMapping(): copy (the contents of) a VoMapping structure
    -# lcmaps_printVoMapping(): print the contents of a VoMapping structure
    \ingroup APIforLcmapsPlugins
*/

#ifndef LCMAPS_VO_DATA_H
#define LCMAPS_VO_DATA_H

/******************************************************************************
                             Define constants
******************************************************************************/
#define LCMAPS_NO_GID (gid_t)(-1) /*!< Invalid GID */

/******************************************************************************
                             Include header files
******************************************************************************/
#include <grp.h>

/******************************************************************************
                               Type definitions
******************************************************************************/

/*!
    \struct lcmaps_vo_data_s
    \brief structure that contains the VO information found
           in the user's gss credential
*/
/*!
    \typedef lcmaps_vo_data_t
    \brief Type of VO information structure
*/
typedef struct lcmaps_vo_data_s
{
    char * vo;         /*!< name of the VO to which the user belongs */
    char * group;      /*!< group within the VO */
    char * subgroup;   /*!< subgroup name */
    char * role;       /*!< the user's role */
    char * capability; /*!< the user's capability */
} lcmaps_vo_data_t;

/*!
    \struct lcmaps_vo_mapping_s
    \brief structure that contains the VO information string (or FQAN) and the
           local Gid it is mapped to.
*/
/*!
    \typedef lcmaps_vo_mapping_t
    \brief Type of VO mapping structure
*/
typedef struct lcmaps_vo_mapping_s
{
    char * vostring;   /*!< VO information string */
    char * groupname;  /*!< groupname the VO information string should be mapped to (according to the
                            groupmapfile) */
    gid_t  gid;        /*!< GID the VO information string should be mapped to (according to the
                            groupmapfile) */
} lcmaps_vo_mapping_t;

/******************************************************************************
 *                 Module definition
 *****************************************************************************/ 

/*
 * VO data section
 */
extern lcmaps_vo_data_t *
lcmaps_createVoData(
    const char * vo,
    const char * group,
    const char * subgroup,
    const char * role,
    const char * capability
);

extern int
lcmaps_deleteVoData(
    lcmaps_vo_data_t ** vo_data
);

extern int
lcmaps_cleanVoData(
    lcmaps_vo_data_t * vo_data
);

extern int
lcmaps_copyVoData(
    lcmaps_vo_data_t * dst_vo_data,
    const lcmaps_vo_data_t * src_vo_data
);

extern int
lcmaps_printVoData(
    int debug_level,
    const lcmaps_vo_data_t * vo_data
);

extern int
lcmaps_stringVoData(
    const lcmaps_vo_data_t * vo_data,
    char * buffer,
    int nchars
);


/*
 * VO group mapping section
 */
extern lcmaps_vo_mapping_t *
lcmaps_createVoMapping(
    const char * vo_data_string,
    const char * groupname,
    const gid_t  gid
);

extern int
lcmaps_deleteVoMapping(
    lcmaps_vo_mapping_t ** vo_mapping
);

extern int
lcmaps_cleanVoMapping(
    lcmaps_vo_mapping_t * vo_mapping
);

extern int
lcmaps_copyVoMapping(
    lcmaps_vo_mapping_t * dst_vo_mapping,
    const lcmaps_vo_mapping_t * src_vo_mapping
);

extern int
lcmaps_printVoMapping(
    int debug_level,
    const lcmaps_vo_mapping_t * vo_mapping
);

#endif /* LCMAPS_VO_DATA_H */

/******************************************************************************
CVS Information:
    $Source: /local/reps/lcgware/fabric_mgt/gridification/lcmaps/include/lcmaps_vo_data.h,v $
    $Date: 2004/09/20 10:12:33 $
    $Revision: 1.7 $
    $Author: maart $
******************************************************************************/
